@@ -20,7 +20,8 @@ __fetch__ = (
 
 
 class BasePesertaDidik(BaseDapodik):
-    __all__ = __fetch__
+    def __add_peserta_didik__(self) -> None:
+        self.__all__ += __fetch__
 
     def __call__(self, sekolah_id: str) -> List[PesertaDidik]:
         return self.peserta_didik(sekolah_id)
@@ -113,3 +114,17 @@ class BasePesertaDidik(BaseDapodik):
         res = self._post("salinPeriodik", data)
         text = res.text.replace("'", '"')
         return self._fd(Message, loads(text))
+
+    def save_pdb(self, pdb: PesertaDidikBaru) -> Message:
+        """Save Pdb to Pd
+
+        Args:
+            pdb (PesertaDidikBaru): Instance dari PesertaDidikBaru
+
+        Returns:
+            Message: Pesan
+        """
+        data = {"pdb_id": pdb.pdb_id}
+        res = self._post("customrest/savePdb", data)
+        text = res.text.replace("'", '"')
+        return self._fd(Message, loads(text))
