@@ -1,7 +1,7 @@
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class ChildDelete:
     child_delete_id: int
     jumlah: int
