@@ -4,7 +4,7 @@ from typing import Optional
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class JenisGugus:
     jenis_gugus_id: str
     jenis_gugus: str
@@ -12,3 +12,6 @@ class JenisGugus:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self):
+        return self.jenis_gugus
