@@ -4,7 +4,7 @@ from typing import Optional
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class JenisLk:
     id_jenis_lk: str
     nm_jenis_lk: str
@@ -13,3 +13,6 @@ class JenisLk:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self):
+        return self.nm_jenis_lk
