@@ -4,7 +4,7 @@ from typing import Optional
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class Jurusan:
     jurusan_id: str
     nama_jurusan: str
@@ -25,3 +25,6 @@ class Jurusan:
     def level_bidang(self):
         # TODO API
         return self.level_bidang_id
+
+    def __str__(self):
+        return self.nama_jurusan
