@@ -6,7 +6,7 @@ from dapodik.base import dataclass
 
 @dataclass(frozen=True, slots=True)
 class SumberDanaSekolah:
-    sumber_dana_sekolah_id: str
+    sumber_dana_sekolah_id: int
     nama: str
     create_date: datetime
     last_update: datetime
