@@ -4,7 +4,7 @@ from typing import Optional
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class TingkatPendidikan:
     tingkat_pendidikan_id: str
     kode: str
@@ -14,3 +14,6 @@ class TingkatPendidikan:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self):
+        return self.nama
