@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, Sekolah, JenisPrasarana, Ptk
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass, freeze
 
 
-@set_meta("id_bangunan", jenis_prasarana=JenisPrasarana, sekolah=Sekolah, ptk=Ptk)
-@attr.dataclass
-class Bangunan(DapodikObject):
+@dataclass
+class Bangunan:
     id_bangunan: str
     jenis_prasarana_id: int
     sekolah_id: str
@@ -46,17 +44,12 @@ class Bangunan(DapodikObject):
     tgl_hapus_buku: Optional[str]
     ket_bangunan: Optional[str]
     asal_data: str
-    create_date: datetime
-    last_update: datetime
-    soft_delete: str
-    last_sync: datetime
-    updater_id: str
     jenis_prasarana_id_str: str
     id_tanah_str: str
     sekolah_id_str: str
     vld_count: int
-
-    @property
-    def kepemilikan_sarpras(self):
-        # TODO API
-        return self.kepemilikan_sarpras_id
+    create_date: datetime = freeze(default=None)
+    last_update: datetime = freeze(default=None)
+    soft_delete: str = freeze(default=None)
+    last_sync: datetime = freeze(default=None)
+    updater_id: str = freeze(default=None)
