@@ -1,12 +1,10 @@
-import attr
 from datetime import datetime
-from dapodik import DapodikObject, Semester
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass, freeze
 
 
-@set_meta("bangunan_longitudinal_id", semester=Semester)
-@attr.dataclass
-class BangunanLongitudinal(DapodikObject):
+@dataclass
+class BangunanLongitudinal:
     id_bangunan: str
     semester_id: str
     rusak_pondasi: str
@@ -24,11 +22,12 @@ class BangunanLongitudinal(DapodikObject):
     rusak_tutup_atap: str
     ket_tutup_atap: str
     nilai_saat_ini: str
-    create_date: datetime
-    last_update: datetime
-    soft_delete: str
-    last_sync: datetime
-    updater_id: str
     id_bangunan_str: str
     semester_id_str: str
     bangunan_longitudinal_id: str
+    bangunan_longitudinal_id_str: str = ""
+    create_date: datetime = freeze(default=None)
+    last_update: datetime = freeze(default=None)
+    soft_delete: str = freeze(default=None)
+    last_sync: datetime = freeze(default=None)
+    updater_id: str = freeze(default=None)
