@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, Semester, Ruang
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass, freeze
 
 
-@set_meta("ruang_longitudinal_id", semester=Semester, ruang=Ruang)
-@attr.dataclass
-class RuangLongitudinal(DapodikObject):
+@dataclass
+class RuangLongitudinal:
     id_ruang: str
     semester_id: str
     blob_id: Optional[str]
@@ -44,11 +42,11 @@ class RuangLongitudinal(DapodikObject):
     rusak_finish_kpj: str
     ket_finish_kpj: str
     berfungsi: str
-    create_date: datetime
-    last_update: datetime
-    soft_delete: str
-    last_sync: datetime
-    updater_id: str
     id_ruang_str: str
     semester_id_str: str
     ruang_longitudinal_id: str
+    create_date: datetime = freeze(default=None)
+    last_update: datetime = freeze(default=None)
+    soft_delete: str = freeze(default=None)
+    last_sync: datetime = freeze(default=None)
+    updater_id: str = freeze(default=None)
