@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, Sekolah, JenisPrasarana
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass, freeze
 
 
-@set_meta("id_tanah", jenis_prasarana=JenisPrasarana, sekolah=Sekolah)
-@attr.dataclass
-class Tanah(DapodikObject):
+@dataclass
+class Tanah:
     id_tanah: str
     jenis_prasarana_id: int
     sekolah_id: str
@@ -32,16 +30,11 @@ class Tanah(DapodikObject):
     luas_lahan_tersedia: str
     no_sertifikat_tanah: str
     asal_data: str
-    create_date: datetime
-    last_update: datetime
-    soft_delete: str
-    last_sync: datetime
-    updater_id: str
     jenis_prasarana_id_str: str
     sekolah_id_str: str
     vld_count: int
-
-    @property
-    def kepemilikan_sarpras(self):
-        # TODO API
-        return self.kepemilikan_sarpras_id
+    create_date: datetime = freeze(default=None)
+    last_update: datetime = freeze(default=None)
+    soft_delete: str = freeze(default=None)
+    last_sync: datetime = freeze(default=None)
+    updater_id: str = freeze(default=None)
