@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, Sekolah
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("id_pi", sekolah=Sekolah)
-@attr.dataclass
-class ProgramInklusi(DapodikObject):
+@dataclass
+class ProgramInklusi:
     id_pi: str
     sekolah_id: str
     kebutuhan_khusus_id: int
