@@ -1,14 +1,11 @@
-from __future__ import annotations
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, SumberAir, Sekolah, Semester
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("sanitasi_id", sekolah=Sekolah, semester=Semester, sumber_air=SumberAir)
-@attr.dataclass
-class Sanitasi(DapodikObject):
+@dataclass
+class Sanitasi:
     sekolah_id: str
     semester_id: str
     sumber_air_id: str
@@ -87,8 +84,3 @@ class Sanitasi(DapodikObject):
     sekolah_id_str: str
     semester_id_str: str
     sanitasi_id: str
-
-    @property
-    def sumber_air_minum(self):
-        # TODO API
-        return self.sumber_air_minum_id
