@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("yayasan_id")
-@attr.dataclass
-class Yayasan(DapodikObject):
+@dataclass
+class Yayasan:
     yayasan_id: str
     nama: str
     alamat_jalan: str
